{ pkgs, lib, ... }:
let
  emailAddress = "felix.albrigtsen@mktv.no";
in {
  imports = [
    ./../../home/base.nix
    ./../../home/alacritty.nix
  ];

  home.packages = with pkgs; [
    bc
    catimg
    chromium
    dig
    element-desktop
    hunspellDicts.en_US
    hunspellDicts.nb_NO
    jq
    libreoffice
    mpv
    oauth2ms
    openssl
    pwgen
    traceroute
    virt-manager
    w3m

    # Window Manager Extras
    bibata-cursors
    cliphist
    hyprcursor
    hypridle
    hyprlock
    hyprpaper
    hyprshot
    hyprswitch
    nautilus
    rofi-rbw-wayland
    swaynotificationcenter
    waybar
    wl-clipboard

    (python312.withPackages (ps: with ps; [
      numpy
      pycryptodome
      requests
    ]))
  ];

  programs = {
    aerc = {
      enable = true;
      package = pkgs.aerc;
    };
    firefox.enable = true;
    git.extraConfig.user.email = emailAddress;
    rbw = {
      enable = true;
      settings = {
        base_url = "https://vault.mktv.no";
        email = emailAddress;
        pinentry = pkgs.pinentry-rofi;
      };
    };
    rofi = {
      enable = true;
      theme = "iggy";
    };
    zsh = {
      shellAliases."rebuild" = "sudo nixos-rebuild switch --flake /config";
      prezto.pmodules = [ "ssh" ];
    };

    neovim.plugins = with pkgs.vimPlugins; [ copilot-vim ];
  };

  xdg.mimeApps = {
    enable = true;

    defaultApplications = {
      "text/html" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/about" = "firefox.desktop";
      "x-scheme-handler/unknown" = "firefox.desktop";
    };
  };

  home.stateVersion = "25.05";
}
